@@ -8,7 +8,7 @@ use Safe;
 use Workflow::Exception qw( condition_error configuration_error );
 use English qw( -no_match_vars );
 
-$Workflow::Condition::Evaluate::VERSION = '1.54';
+$Workflow::Condition::Evaluate::VERSION = '1.55';
 
 my @FIELDS = qw( test );
 __PACKAGE__->mk_accessors(@FIELDS);
@@ -24,16 +24,14 @@ sub _init {
         configuration_error
             "The evaluate condition must be configured with 'test'";
     }
-    $self->log->is_info
-        && $self->log->info("Added evaluation condition with '$params->{test}'");
+    $self->log->info("Added evaluation condition with '$params->{test}'");
 }
 
 sub evaluate {
     my ( $self, $wf ) = @_;
 
     my $to_eval = $self->test;
-    $self->log->is_info
-        && $self->log->info("Evaluating '$to_eval' to see if it returns true...");
+    $self->log->info("Evaluating '$to_eval' to see if it returns true...");
 
     # Assign our local stuff to package variables...
     $Workflow::Condition::Evaluate::context = $wf->context->param;
@@ -48,10 +46,9 @@ sub evaluate {
             "Condition expressed in code threw exception: $EVAL_ERROR";
     }
 
-    $self->log->is_debug
-        && $self->log->debug( "Safe eval ran ok, returned: '"
-            . ( defined $rv ? $rv : '<undef>' )
-            . "'" );
+    $self->log->debug( "Safe eval ran ok, returned: '",
+                       ( defined $rv ? $rv : '<undef>' ),
+                       "'" );
     unless ($rv) {
         condition_error "Condition expressed by test '$to_eval' did not ",
             "return a true value.";
@@ -71,7 +68,7 @@ Workflow::Condition::Evaluate - Inline condition that evaluates perl code for tr
 
 =head1 VERSION
 
-This documentation describes version 1.54 of this package
+This documentation describes version 1.55 of this package
 
 =head1 SYNOPSIS
 
