@@ -6,7 +6,7 @@ use base qw( Workflow::Condition );
 use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( condition_error );
 
-$Workflow::Condition::HasUser::VERSION = '1.54';
+$Workflow::Condition::HasUser::VERSION = '1.55';
 
 my $DEFAULT_USER_KEY = 'current_user';
 
@@ -18,8 +18,7 @@ sub _init {
 
 sub evaluate {
     my ( $self, $wf ) = @_;
-    $self->log->is_debug
-        && $self->log->debug( "Trying to execute condition ", ref $self );
+    $self->log->debug( "Trying to execute condition ", ref $self );
     my $user_key     = $self->param('user_key');
     my $current_user = $wf->context->param($user_key);
     $self->log->debug( "Current user in the context is '$current_user' retrieved ",
@@ -42,7 +41,7 @@ Workflow::Condition::HasUser - Condition to determine if a user is available
 
 =head1 VERSION
 
-This documentation describes version 1.54 of this package
+This documentation describes version 1.55 of this package
 
 =head1 SYNOPSIS
 
