@@ -8,7 +8,7 @@ use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( persist_error );
 use English qw( -no_match_vars );
 
-$Workflow::Persister::DBI::SequenceId::VERSION = '1.54';
+$Workflow::Persister::DBI::SequenceId::VERSION = '1.55';
 
 my @FIELDS = qw( log sequence_name sequence_select );
 __PACKAGE__->mk_accessors(@FIELDS);
@@ -25,8 +25,7 @@ sub new {
 sub pre_fetch_id {
     my ( $self, $dbh ) = @_;
     my $full_select = sprintf $self->sequence_select, $self->sequence_name;
-    $self->log->is_debug
-        && $self->log->debug("SQL to fetch sequence: $full_select");
+    $self->log->debug("SQL to fetch sequence: ", $full_select);
     my ($row);
     eval {
         my $sth = $dbh->prepare($full_select);
@@ -54,7 +53,7 @@ Workflow::Persister::DBI::SequenceId - Persister to fetch ID from a sequence
 
 =head1 VERSION
 
-This documentation describes version 1.54 of this package
+This documentation describes version 1.55 of this package
 
 =head1 SYNOPSIS
 
