@@ -11,7 +11,7 @@ use Exception::Class;
 use Workflow::Factory qw( FACTORY );
 use English qw( -no_match_vars );
 
-$Workflow::State::VERSION = '1.54';
+$Workflow::State::VERSION = '1.55';
 
 my @FIELDS   = qw( state description type );
 my @INTERNAL = qw( _test_condition_count _factory );
@@ -27,6 +27,17 @@ sub get_conditions {
     return @{ $self->{_conditions}{$action_name} };
 }
 
+sub get_action {
+    my ( $self, $wf, $action_name ) = @_;
+    my $common_config =
+        $self->_factory->get_action_config($wf, $action_name);
+    my $state_config  = $self->{_actions}{$action_name};
+    my $config        = { %{$common_config}, %{$state_config} };
+    my $action_class  = $common_config->{class};
+
+    return $action_class->new( $wf, $config );
+}
+
 sub contains_action {
     my ( $self, $action_name ) = @_;
     return $self->{_actions}{$action_name};
@@ -94,12 +105,7 @@ sub evaluate_action {
 
     my @conditions = $self->get_conditions($action_name);
     foreach my $condition (@conditions) {
-        my $condition_name;
-        if ( exists $condition->{name} ) {    # hash only, no object
-            $condition_name = $condition->{name};
-        } else {
-            $condition_name = $condition->name;
-        }
+        my $condition_name = $condition->name;
 
         my $rv;
         eval {
@@ -161,9 +167,7 @@ sub get_autorun_action_name {
         workflow_error
             "$pre_error there are no actions available for execution.";
     }
-    $self->log->is_debug
-        && $self->log->debug(
-        "Auto-running state '$state' with action '$actions[0]'");
+    $self->log->debug("Auto-running state '$state' with action '$actions[0]'");
     return $actions[0];
 }
 
@@ -203,8 +207,7 @@ sub init {
 
     my $class = ref $self;
 
-    $self->log->is_debug
-        && $self->log->debug("Constructing '$class' object for state $name");
+    $self->log->debug("Constructing '$class' object for state $name");
 
     $self->state($name);
     $self->_factory($factory);
@@ -259,9 +262,8 @@ sub _assign_resulting_state_from_array {
         workflow_error "Errors found assigning 'resulting_state' to ",
             "action '$action_name' in state '$name': ", join '; ', @errors;
     }
-    $self->log->is_debug
-        && $self->log->debug( "Assigned multiple resulting states in '$name' and ",
-        "action '$action_name' from array ok" );
+    $self->log->debug( "Assigned multiple resulting states in '$name' and ",
+                       "action '$action_name' from array ok" );
     return \%new_resulting;
 }
 
@@ -275,8 +277,7 @@ sub _add_action_config {
             "is required -- if you do not want the state to ",
             "change, use the value '$no_change_value'.";
     }
-    $self->log->is_debug
-        && $self->log->debug("Adding '$state' '$action_name' config");
+    $self->log->debug("Adding '$state' '$action_name' config");
     $self->{_actions}{$action_name} = $action_config;
     my @action_conditions = $self->_create_condition_objects($action_config);
     $self->{_conditions}{$action_name} = \@action_conditions;
@@ -301,24 +302,11 @@ sub _create_condition_objects {
                 }
                 );
         } else {
-            if ( $condition_info->{name} =~ m{ \A ! }xms ) {
-                $self->log->is_debug
-                    && $self->log->debug(
-                    "Condition starts with !, pushing hash with name only");
-
-                # push a hashref only, not a real object
-                # the real object will be gotten from the factory
-                # if needed in evaluate_action
-                push @condition_objects,
-                    { 'name' => $condition_info->{name} };
-            } else {
-                $self->log->is_info
-                    && $self->log->info(
-                    "Fetching condition '$condition_info->{name}'");
-                push @condition_objects,
-                    $self->_factory()
-                    ->get_condition( $condition_info->{name}, $self->type() );
-            }
+            $self->log->info(
+                "Fetching condition '$condition_info->{name}'");
+            push @condition_objects,
+                $self->_factory()
+                ->get_condition( $condition_info->{name}, $self->type() );
         }
     }
     return @condition_objects;
@@ -356,7 +344,7 @@ Workflow::State - Information about an individual state in a workflow
 
 =head1 VERSION
 
-This documentation describes version 1.54 of this package
+This documentation describes version 1.55 of this package
 
 =head1 SYNOPSIS
 
@@ -450,6 +438,14 @@ Returns a list of L<Workflow::Condition> objects for action
 C<$action_name>. Throws exception if object does not contain
 C<$action_name> at all.
 
+=head3 get_action( $workflow, $action_name )
+
+Returns an L<Workflow::Action> instance initialized using both the
+global configuration provided to the named action in the "action
+configuration" provided to the factory as well as any configuration
+specified as part of the listing of actions in the state of the
+workflow declaration.
+
 =head3 contains_action( $action_name )
 
 Returns true if this state contains action C<$action_name>, false if
@@ -498,7 +494,7 @@ Returns name of action to be used for autorunning the state.
 
 =head3 clear_condition_cache ( )
 
-Deprecated, kept for 1.54 compatibility.
+Deprecated, kept for 1.55 compatibility.
 
 Used to empties the condition result cache for a given state.
 
